@@ -47,7 +47,7 @@ void clust_update_DDP(arma::vec data,
 void update_w_DDP(arma::vec &w,
                   double mass,
                   double wei,
-                  int n_approx_unif,
+                  double var_MH_step,
                   arma::vec zeta,
                   arma::vec clust,
                   arma::vec group,
